[MOAB-dev] r3602 - MOAB/trunk/src/io

bmsmith6 at wisc.edu bmsmith6 at wisc.edu
Fri Mar 12 13:19:36 CST 2010


Author: bmsmith
Date: 2010-03-12 13:19:36 -0600 (Fri, 12 Mar 2010)
New Revision: 3602

Modified:
   MOAB/trunk/src/io/ReadCGM.cpp
   MOAB/trunk/src/io/ReadCGM.hpp
Log:
Tag the file_set with the modeling engine's absolute tolerance. This is useful for watertightness work.



Modified: MOAB/trunk/src/io/ReadCGM.cpp
===================================================================
--- MOAB/trunk/src/io/ReadCGM.hpp	2010-03-12 18:39:29 UTC (rev 3601)
+++ MOAB/trunk/src/io/ReadCGM.hpp	2010-03-12 19:19:36 UTC (rev 3602)
@@ -97,7 +97,8 @@
     //! interface instance
   MBInterface* mdbImpl;
 
-  MBTag geom_tag, id_tag, name_tag, category_tag, faceting_tol_tag;
+  MBTag geom_tag, id_tag, name_tag, category_tag, faceting_tol_tag, 
+        geometry_resabs_tag;
 };
 
 #endif



More information about the moab-dev mailing list
--- MOAB/trunk/src/io/ReadCGM.cpp	2010-03-12 18:39:29 UTC (rev 3601)
+++ MOAB/trunk/src/io/ReadCGM.cpp	2010-03-12 19:19:36 UTC (rev 3602)
@@ -59,7 +59,8 @@
 { return new ReadCGM( iface ); }
 
 ReadCGM::ReadCGM(MBInterface *impl)
-  : geom_tag(0), id_tag(0), name_tag(0), category_tag(0), faceting_tol_tag(0)
+  : geom_tag(0), id_tag(0), name_tag(0), category_tag(0), faceting_tol_tag(0), 
+    geometry_resabs_tag(0)
 {
   assert(NULL != impl);
   mdbImpl = impl;
@@ -88,6 +89,9 @@
   rval = mdbImpl->tag_create("FACETING_TOL", sizeof(double), MB_TAG_SPARSE,
 			     MB_TYPE_DOUBLE, faceting_tol_tag, 0, true );
   assert(!rval);
+  rval = mdbImpl->tag_create("GEOMETRY_RESABS", sizeof(double), MB_TAG_SPARSE,
+			     MB_TYPE_DOUBLE, geometry_resabs_tag, 0, true );
+  assert(!rval);
 }
 
 ReadCGM::~ReadCGM()
@@ -145,10 +149,12 @@
   if(MB_SUCCESS == opts.match_option(name,value)) 
     act_att = false; 
 
   // tag the file_set with the faceting_tol
   if (file_set) {
     rval = mdbImpl->tag_set_data( faceting_tol_tag, file_set, 1, &faceting_tol );
     if(MB_SUCCESS != rval) return rval;
+    rval = mdbImpl->tag_set_data( geometry_resabs_tag, file_set, 1, &GEOMETRY_RESABS );
+    if(MB_SUCCESS != rval) return rval;
   }
 
   // CGM data
@@ -145,10 +149,12 @@
     act_att = false; 
 
-  // tag the file_set with the faceting_tol
+  // tag the file_set with the faceting_tol and geometry absolute resolution
   if (file_set) {
     rval = mdbImpl->tag_set_data( faceting_tol_tag, file_set, 1, &faceting_tol );

Modified: MOAB/trunk/src/io/ReadCGM.hpp
===================================================================